AutoQueryMut

Struct AutoQueryMut 

pub struct AutoQueryMut<'a, T: Any> { /* private fields */ }
AutoQueryMut is a struct that allows quick access of every instance of a single component mutably. (The immutable variant is AutoQuery)

WARNING

If you ever get an error: “thread ‘main’ panicked at ‘already borrowed: BorrowMutError’” this means you have two mutable borrows to the same data. This could be because you have two mutable auto queries in the same scope. The solution is to either drop them manually or to enclose them in a block:

use sceller::prelude::*;

struct Health; // example struct

{
    let ents = Entities::default();

    let query = Query::new(&ents);
    let mut auto = query.auto::<Health>();
    
    // <snip!>
} //<- ensures that the mutable borrow is dropped at the end of this block

It contains ‘phantom’ which is a PhantomData, since the query needs to contain a type for ease of use. And a reference to ‘Entities’.

Pretty much all of this struct’s functionality is implmenting IntoIterator, in which the reference to Entities is used to get all components of the AutoQueryMut’s type ‘T’.

Implementations

Source

impl<'a, T: 'static> AutoQueryMut<'a, T>

pub fn new(entities: &'a Entities) -> Self